package com.huimv.farm.damsubsidy.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.huimv.farm.damsubsidy.common.utils.Result;
import com.huimv.farm.damsubsidy.common.utils.ResultCode;
import com.huimv.farm.damsubsidy.entity.*;
import com.huimv.farm.damsubsidy.mapper.AreaByLevelMapper;
import com.huimv.farm.damsubsidy.service.IAreaByLevelService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.HashMap;
import java.util.List;

// Author: Tinger-XXX
// Time: 2023/5/7 14:34
@Service
public class AreaByLevelServiceImpl implements IAreaByLevelService {
    @Autowired
    private AreaByLevelMapper dbMapper;

    @Override
    public Result listTypes() {
        List<AreaType> types = dbMapper.listTypes();
        return new Result(ResultCode.SUCCESS, types);
    }

    @Override
    public Result listLevels() {
        List<AreaLevel> levels = dbMapper.listLevels();
        return new Result(ResultCode.SUCCESS, levels);
    }

    @Override
    public Result getInfo() {
        List<AreaType> types = dbMapper.listTypes();
        List<AreaLevel> levels = dbMapper.listLevels();
        HashMap<String, Object> map = new HashMap<>();
        map.put("types", types);
        map.put("levels", levels);
        return new Result(ResultCode.SUCCESS, map);
    }

    @Override
    public Result listProvinces() {
        QueryWrapper<AreaAll> wrapper = new QueryWrapper<>();
        wrapper.eq("level", "1+");
        List<AreaAll> provinces = dbMapper.selectList(wrapper);
        return new Result(ResultCode.SUCCESS, provinces);
    }

    @Override
    public Result listChildrenOf(String currentId, String childLevel) {
        QueryWrapper<AreaAll> wrapper = new QueryWrapper<>();
        wrapper.likeRight("id", currentId)
                .eq("level", childLevel);
        List<AreaAll> children = dbMapper.selectList(wrapper);
        return new Result(ResultCode.SUCCESS, children);
    }

    @Override
    public Result insert(AreaAll one) {
        int res = dbMapper.insert(one);
        return new Result(ResultCode.SUCCESS, "inserted <" + res + "> record");
    }

    @Override
    public Result insert(List<AreaAll> batch) {
        int num = 0;
        for (AreaAll one: batch) num += dbMapper.insert(one);
        return new Result(ResultCode.SUCCESS, "inserted <" + num + "> record(s)");
    }

    @Override
    public Result delete(String id) {
        int res = dbMapper.deleteById(id);
        return new Result(ResultCode.SUCCESS, "deleted <" + res + "> record(s)");
    }

    @Override
    public Result update(AreaAll item) {
        int res = dbMapper.updateById(item);
        return new Result(ResultCode.SUCCESS, "updated <" + res + "> record(s)");
    }
}
